#ifndef ACL_H
#define ACL_H
/*
	ACL (Access List) structure definitions
*/ 

#include <netinet/in.h>
#include <arpa/inet.h>

#include "types.h"

typedef struct acl_s {  INT		perm;
			in_addr_t	addr;
			in_addr_t	mask; } acl_t;

#define PERM_NONE	0
#define	PERM_READ	1
#define	PERM_WRITE	2
#define	PERM_CREATE	4
#define PERM_APPEND	8
#define	PERM_DENY	0x10

#define PERM_MASK       0x0f
#define PERM_EMASK      0x1f
#define PERM_CLEAR      0x20
#define PERM_ALIAS      0x40

#define PERM_WRCRAP	(PERM_WRITE | PERM_CREATE | PERM_APPEND)


#define IPMASK_HOST	((in_addr_t)0xffffffff)
#define IPMASK_ANY	((in_addr_t)0)

#define C_IPMASK_HOST	"255.255.255.255"
#define C_IPMASK_ANY	"0.0.0.0"

typedef struct perm_s  { CHAR *name;
                         INT  mask; } perm_t;

#ifdef PERMTABLES

#define MKS ",|"

static perm_t permtable[] = {
	{ "deny",	PERM_DENY  | PERM_CLEAR },
	{ "read",	PERM_READ },
	{ "write",	PERM_WRITE },
	{ "append",	PERM_APPEND },
	{ "create",	PERM_CREATE },
	{ "permit",	PERM_READ  | PERM_WRITE | PERM_CLEAR | PERM_ALIAS },
	{ "readonly",	PERM_READ  | PERM_CLEAR | PERM_ALIAS },
	{ "writeonly",	PERM_WRITE | PERM_CLEAR | PERM_ALIAS },
	{ "readwrite",	PERM_READ  | PERM_WRITE | PERM_CLEAR | PERM_ALIAS },
	{ NULL,		0 } };
#endif

#endif /* ACL_H */
